@@ -1,7 +1,6 @@
+from .figure import figure
+#from . import style
 import sys
 import os
 cwd = os.path.dirname(os.path.realpath(__file__))
 sys.path.append(cwd)
-
-from . import style
-from .figure import figure
\ No newline at end of file
